@@ -3,6 +3,7 @@ The Monitor connects to sources, evaluates rules, sends the resulting metrics to
 """
 from __future__ import annotations
 
+import sys
 from collections.abc import Iterable
 from typing import get_type_hints
 from uuid import uuid4
@@ -50,22 +51,34 @@ class Monitor:
         if store_cls not in self.stores:
             self.stores.append(store_cls)
 
-    def __resolve_stores_from_attribute(self, rule_cls) -> None:
+    def __resolve_stores_from_attribute(self, rule_cls: RuleClass) -> None:
         """Get the stores from stores = []"""
         for store_cls in rule_cls.stores:
             self._add_store(store_cls)
 
-    def __resolve_sources_from_attribute(self, rule_cls) -> None:
+    def __resolve_sources_from_attribute(self, rule_cls: RuleClass) -> None:
         """Get the sources from sources = []"""
         for source_cls in rule_cls.sources:
             self._add_source(source_cls)
 
-    def __resolve_sources_from_init(self, rule_cls) -> None:
-        self._source_map[rule_cls] = {}
+    def _get_annotations(self, rule_cls: RuleClass) -> JDict:
+        """Getting annonations for the constructor."""
+        if sys.version_info.minor > 8:
+            try:
+                return get_type_hints(rule_cls.__init__, include_extras=True)
+            except NameError:
+                pass
+
         try:
-            annos = get_type_hints(rule_cls.__init__)
+            return get_type_hints(rule_cls.__init__)
         except NameError:
-            annos = rule_cls.__init__.__annotations__
+            pass
+
+        return rule_cls.__init__.__annotations__
+
+    def __resolve_sources_from_init(self, rule_cls: RuleClass) -> None:
+        self._source_map[rule_cls] = {}
+        annos = self._get_annotations(rule_cls)
         for arg, source_cls in annos.items():
             if arg == "monitor":
                 self._source_map[rule_cls]["monitor"] = self.__class__
