@@ -1,5 +1,7 @@
 from __future__ import annotations
 
+from datetime import datetime, timedelta
+
 from sinai.metrics import AGGREGATION_CLASSES
 from sinai.rules.base import Rule
 from sinai.sources.base import MetricSource
@@ -29,8 +31,9 @@ class MetricAggregationRule(Rule):
     mean: MetricClasses = []
     mode: MetricClasses = []
     median: MetricClasses = []
-    last_only = False
-    exclude_checked = False
+    last_only: bool = False
+    exclude_checked: bool = False
+    recent_only: bool = False
 
     def __init__(self, monitor: MonitorInstance, metric_source: MetricSource):
         super().__init__(monitor)
@@ -57,6 +60,10 @@ class MetricAggregationRule(Rule):
         metric.process_data_points(data_points)
         self.metrics.append(metric)
 
+    def recent(self) -> datetime:
+        """Subclass and redefine to change the definition of recent."""
+        return datetime.utcnow() - timedelta(hours=4)
+
     def _get_metric_instances(
         self, source_cls: MetricSourceClass, aggregation_name: str
     ) -> MetricList:
@@ -68,6 +75,8 @@ class MetricAggregationRule(Rule):
                 filter["monitor_id"] = self.monitor.id
             if self.exclude_checked:
                 filter["checked"] = False
+            if self.recent_only:
+                filter["updated_at"] = {"$gt": self.recent()}
             instances = source.get(**filter)
             metric_instances.extend(instances)
         return metric_instances
